@@ -1,4 +1,4 @@
-use swc_common::{sync::Lrc, FileName, SourceMap, DUMMY_SP};
+use swc_common::{sync::Lrc, SourceMap, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::quote_ident;
 use swc_ecma_visit::{noop_fold_type, Fold};
